@@ -59,6 +59,10 @@ class ModelAttribute(ModelLoader, BaseAttribute):
     """
 
     def __init__(self, model=None, **kwargs):
+        if not model:
+            raise sheraf.exceptions.SherafException(
+                "ModelAttribute requires model parameter."
+            )
         super().__init__(default=None, model=model, **kwargs)
 
     def values(self, model):
@@ -66,7 +70,11 @@ class ModelAttribute(ModelLoader, BaseAttribute):
         By default :class:`~sheraf.attributes.models.ModelAttribute` are indexed on
         their identifier.
         """
-        return {model.identifier}
+        return {
+            (model.table, model.identifier)
+            if isinstance(self.model, (tuple, list))
+            else model.identifier
+        }
 
     def deserialize(self, value):
         if isinstance(value, tuple):
